@@ -1,7 +1,6 @@
 import os
 import sys
 import stat
-from backstage.act.act import Act
 import subprocess
 
 class Venue():
@@ -98,8 +97,9 @@ class Venue():
         acts_list = os.listdir(acts_root)
         for a in acts_list:
             try:
-                act=Act(self,a)
-                self.acts.append(act)
+                pass
+                #act=Act(self,a)
+                #self.acts.append(act)
             except:
                 pass
 
